import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Structure } from '@gouvfr-anct/mediation-numerique';
import { ButtonType } from '@gouvfr-anct/mediation-numerique/shared';
import { NotificationService } from '../../services/notification.service';
import { StructureService } from '../../services/structure.service';
import { UserService } from '../../services/user.service';

@Component({
  selector: 'app-structure-exclude',
  templateUrl: './structure-exclude.component.html',
  styleUrls: ['./structure-exclude.component.scss'],
})
export class StructureExcludeComponent implements OnInit {
  constructor(
    private router: Router,
    private route: ActivatedRoute,
    private structureService: StructureService,
    private notificationService: NotificationService,
    private userService: UserService
  ) {}

  public alreadyExcluded: boolean = false;
  public buttonTypeEnum = ButtonType;
  public newMemberName: string;
  public structure: Structure;
  private structureId: string;

  ngOnInit(): void {
    this.route.queryParamMap.subscribe(async (params) => {
      if (!params.get('id') || !params.get('userId')) {
        this.router.navigateByUrl('/acteurs');
      } else {
        this.structureId = params.get('id');
        this.userService.getUser(params.get('userId')).subscribe((res) => {
          this.newMemberName = res.name + ' ' + res.surname;
        });
        this.structureService.getStructureWithOwners(params.get('id'), null).subscribe((res) => {
          this.structure = res.structure;
          const owners = res.owners;
          const isOwner = owners.find((owner) => owner._id === params.get('userId'));
          if (!isOwner) {
            this.alreadyExcluded = true;
          }
        });
      }
    });
  }

  public close(): void {
    this.router.navigateByUrl(`/acteurs?id=${this.structureId}`);
  }

  public exclude(): void {
    this.route.queryParamMap.subscribe((params) => {
      if (params.get('id') && params.get('userId')) {
        this.structureService.removeOwnerFromStructure(params.get('userId'), params.get('id')).subscribe(
          () => {
            this.notificationService.showSuccess(
              `${this.newMemberName} a bien été exclu de ${this.structure.structureName}`,
              ''
            );
            this.router.navigateByUrl(`/acteurs?id=${this.structureId}`);
          },
          () => {
            this.notificationService.showError(
              `${this.newMemberName} n'a pas pu être exclu de ${this.structure.structureName}. Merci de réessayer plus tard.`,
              "Echec de l'exclusion"
            );
            this.router.navigateByUrl(`/acteurs?id=${this.structureId}`);
          }
        );
      }
    });
  }
}
